.. :changelog:

History
-------

0.5.1 (2013-10-16)
++++++++++++++++++

- Icon can be set for display element in list table head
- Deprecation info in list macro
- More configuration options in create and update macros and deprecation info in this macros
- HTML type action can be created
- Action can be disabled

0.5.0 (2013-10-11)
++++++++++++++++++

- API change for list configuration and list templates (object urls now generated in object class using call method)
- Changes in Jinja2 macros - breaking some macros API

0.4.2 (2013-10-08)
++++++++++++++++++

- Adding call and visable functionality for object actions in pager

0.4.1 (2013-09-30)
++++++++++++++++++

- Macros for create and update pages

0.4.0 (2013-09-29)
++++++++++++++++++

- Generators for list type page using Pager - first version for configuration API (example in Lightningwolf-SMP Projekct)
- API change for Pager
- API change for methods in Navbar class

0.3.2 (2013-09-15)
++++++++++++++++++

- Pager

0.3.1 (2013-09-15)
++++++++++++++++++

- New macros: filters, batch_actions, actions

0.3.0 (2013-09-15)
++++++++++++++++++

- New navbar methods and class location
- New macros location
- Start of Flask-Babel integration
- Start of Flask-Bootstrap integration

0.2.4 (2013-09-11)
++++++++++++++++++

- Navbar with dropdown, btn group, caret

0.2.3 (2013-09-03)
++++++++++++++++++

- Flask-Principal can be used to restrict visibility of navbar section

0.2.2 (2013-09-02)
++++++++++++++++++

- API change for Navbar creator

0.1.0 (2013-08-29)
++++++++++++++++++

- Initial version
